==> rn-shiki-0.0.37-68.tgz: package/src/components/syntax/SyntaxHighlighter.tsx <==
/* eslint-disable no-console */
import type { ThemedToken, ThemeRegistration } from '@shikijs/types'
import type { ScrollViewProps, StyleProp, TextStyle, ViewStyle } from 'react-native'
import type { SyntaxHighlighterProps } from 'src/types/shiki'
import React, { useMemo } from 'react'
import { Platform, ScrollView, StyleSheet, Text, View } from 'react-native'
import { useSyntaxHighlighter } from '../../hooks/useSyntaxHighlighter'

const monospaceFont = Platform.select({
  ios: 'Menlo',
  android: 'monospace',
  default: 'monospace',
})

function transformThemeToStyles(theme: ThemeRegistration) {
  const defaultBackground = theme.colors?.['editor.background']
  const foreground = theme.colors?.['editor.foreground']

  console.log('[SyntaxHighlighter] Theme colors:', {
    background: defaultBackground,
    foreground,
    allColors: theme.colors,
  })

  const styles = StyleSheet.create({
    scrollView: {
      flex: 1,
      minHeight: 20,
    },
    codeContainer: {
      padding: 16,
      minWidth: '100%',
    },
    lineContainer: {
      flexDirection: 'row',
      flexWrap: 'wrap',
    },
    baseToken: {
      fontFamily: monospaceFont,
    },
  })

  const colorStyles = new Map<string, TextStyle>()

  return {
    base: styles,
    background: defaultBackground,
    getTokenStyle: (token: ThemedToken): TextStyle => {
      const key = `${token.color || ''}-${token.fontStyle || ''}`

      if (!colorStyles.has(key)) {
        const style: TextStyle = {
          color: token.color || foreground,
          fontStyle: (token.fontStyle ? 'italic' : 'normal') as 'italic' | 'normal',
          fontWeight: token.fontStyle ? 'bold' : 'normal',
        }
        console.log('[SyntaxHighlighter] Created new token style:', { key, token, style })
        colorStyles.set(key, style)
      }

      return colorStyles.get(key)!
    },
  }
}

interface Props extends SyntaxHighlighterProps {
  scrollViewProps?: ScrollViewProps
  textStyle?: StyleProp<TextStyle>
  containerStyle?: StyleProp<ViewStyle>
}

const SyntaxHighlighter: React.FC<Props> = ({ text, language, languageId, theme, fontSize = 14, scrollViewProps, textStyle, containerStyle }) => {
  const { tokens } = useSyntaxHighlighter({
    text,
    language,
    languageId: languageId || String(language),
    theme,
  })

  console.log('[SyntaxHighlighter] Received tokens:', tokens.length, 'lines')
  console.log(
    '[SyntaxHighlighter] First line tokens:',
    tokens[0]?.map(t => ({
      content: t.content,
      color: t.color,
      fontStyle: t.fontStyle,
    })),
  )

  const styles = useMemo(() => transformThemeToStyles(theme as ThemeRegistration), [theme])

  return (
    <ScrollView
      horizontal
      {...scrollViewProps}
      style={[styles.base.scrollView, scrollViewProps?.style]}
      contentContainerStyle={[styles.base.codeContainer, { backgroundColor: theme.colors?.['editor.background'] || '#1e1e1e' }, scrollViewProps?.contentContainerStyle, containerStyle]}
    >
      <View onStartShouldSetResponder={() => true}>
        {tokens.map((line, rowIndex) => (
          <View key={rowIndex} style={[styles.base.lineContainer, { backgroundColor: theme.colors?.['editor.background'] || '#1e1e1e' }]}>
            {line.map((token, tokenIndex) => {
              const tokenStyle = styles.getTokenStyle(token)
              if (rowIndex === 0 && tokenIndex === 0) {
                console.log('[SyntaxHighlighter] First token styles:', {
                  base: styles.base.baseToken,
                  token: tokenStyle,
                  fontSize,
                  custom: textStyle,
                })
              }
              return (
                <Text key={`${rowIndex}-${tokenIndex}`} style={[styles.base.baseToken, tokenStyle, { fontSize }, textStyle]}>
                  {token.content}
                </Text>
              )
            })}
          </View>
        ))}
      </View>
    </ScrollView>
  )
}

export default SyntaxHighlighter

==> rn-shiki-0.0.37-69.tgz: package/src/components/syntax/SyntaxHighlighter.tsx <==
/* eslint-disable no-console */
import type { ThemedToken, ThemeRegistration } from '@shikijs/types'
import type { ScrollViewProps, StyleProp, TextStyle, ViewStyle } from 'react-native'
import type { SyntaxHighlighterProps } from 'src/types/shiki'
import React, { useMemo } from 'react'
import { Platform, ScrollView, StyleSheet, Text, View } from 'react-native'
import { processTokens } from 'src/syntax/highlighter'
import { useSyntaxHighlighter } from '../../hooks/useSyntaxHighlighter'

const monospaceFont = Platform.select({
  ios: 'Menlo',
  android: 'monospace',
  default: 'monospace',
})

function transformThemeToStyles(theme: ThemeRegistration) {
  const defaultBackground = theme.colors?.['editor.background']
  const foreground = theme.colors?.['editor.foreground']

  console.log('[SyntaxHighlighter] Theme colors:', {
    background: defaultBackground,
    foreground,
    allColors: theme.colors,
  })

  const styles = StyleSheet.create({
    scrollView: {
      flex: 1,
      minHeight: 20,
    },
    codeContainer: {
      padding: 16,
      minWidth: '100%',
    },
    lineContainer: {
      flexDirection: 'row',
      flexWrap: 'wrap',
    },
    baseToken: {
      fontFamily: monospaceFont,
    },
  })

  const colorStyles = new Map<string, TextStyle>()

  return {
    base: styles,
    background: defaultBackground,
    getTokenStyle: (token: ThemedToken): TextStyle => {
      const key = `${token.color || ''}-${token.fontStyle || ''}`

      if (!colorStyles.has(key)) {
        const style: TextStyle = {
          color: token.color || foreground,
          fontStyle: (token.fontStyle ? 'italic' : 'normal') as 'italic' | 'normal',
          fontWeight: token.fontStyle ? 'bold' : 'normal',
        }
        console.log('[SyntaxHighlighter] Created new token style:', { key, token, style })
        colorStyles.set(key, style)
      }

      return colorStyles.get(key)!
    },
  }
}

interface Props extends SyntaxHighlighterProps {
  scrollViewProps?: ScrollViewProps
  textStyle?: StyleProp<TextStyle>
  containerStyle?: StyleProp<ViewStyle>
}

const SyntaxHighlighter: React.FC<Props> = ({ text, language, languageId, theme, fontSize = 14, scrollViewProps, textStyle, containerStyle }) => {
  const { tokens: rawTokens } = useSyntaxHighlighter({
    text,
    language,
    languageId: languageId || String(language),
    theme,
  })

  const tokens = useMemo(() => rawTokens.map(line => processTokens(line) as ThemedToken[]), [rawTokens])

  console.log('[SyntaxHighlighter] Processed tokens:', tokens)

  const styles = useMemo(() => transformThemeToStyles(theme as ThemeRegistration), [theme])

  return (
    <ScrollView
      horizontal
      {...scrollViewProps}
      style={[styles.base.scrollView, scrollViewProps?.style]}
      contentContainerStyle={[styles.base.codeContainer, { backgroundColor: theme.colors?.['editor.background'] || '#1e1e1e' }, scrollViewProps?.contentContainerStyle, containerStyle]}
    >
      <View onStartShouldSetResponder={() => true}>
        {tokens.map((line, rowIndex) => (
          <View key={rowIndex} style={[styles.base.lineContainer, { backgroundColor: theme.colors?.['editor.background'] || '#1e1e1e' }]}>
            {line.map((token, tokenIndex) => {
              const tokenStyle = styles.getTokenStyle(token)
              if (rowIndex === 0 && tokenIndex === 0) {
                console.log('[SyntaxHighlighter] First token styles:', {
                  base: styles.base.baseToken,
                  token: tokenStyle,
                  fontSize,
                  custom: textStyle,
                })
              }
              return (
                <Text key={`${rowIndex}-${tokenIndex}`} style={[styles.base.baseToken, tokenStyle, { fontSize }, textStyle]}>
                  {token.content}
                </Text>
              )
            })}
          </View>
        ))}
      </View>
    </ScrollView>
  )
}

export default SyntaxHighlighter
